<?xml version="1.0"?>
<xsl:stylesheet
	version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsd="http://www.w3.org/2001/XMLSchema" 
	xmlns:spectrum="http://www.mda.org.uk/spectrum-2" >

<xsl:template match="/">
	<html>
		<head>
			<title>Schema listing</title>
			<link rel="stylesheet" type="text/css" href="schemaDisplay.css"/>
		</head>
		<body>
			<xsl:apply-templates/>
		</body>
	</html>
</xsl:template>

<xsl:template match="xsd:schema/xsd:annotation/xsd:documentation">
  <h1><xsl:apply-templates/></h1>
</xsl:template>

<xsl:template match="xsd:documentation">
	<div>
		<xsl:apply-templates/>
	</div>
</xsl:template>

<xsl:template match="xsd:complexType[@name]">
	<div>
		<a name="{@name}">
			<h2>
				Complex type: <xsl:value-of select="@name" />
			</h2>
		</a>
		<xsl:apply-templates />
	</div>
</xsl:template>

<xsl:template match="xsd:sequence">
	<div>
		<h3>Sequence:</h3>
		<xsl:apply-templates />
  </div>
</xsl:template>

<xsl:template match="xsd:choice">
	<div>
		<h3>Choice:</h3>
		<xsl:apply-templates />
  </div>
</xsl:template>

<xsl:template name="displayElementName">
	<xsl:choose>
		<xsl:when test="//xsd:complexType[@name=current()/@name]">
			<a href="{concat('#', @name)}"><xsl:value-of select="@name" /> (<xsl:apply-templates select="@type|@minOccurs|@maxOccurs"/>)</a>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="@name" /> (<xsl:apply-templates select="@type|@minOccurs|@maxOccurs"/>)
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="xsd:element[not(*)]">
	<div>
		<h3>
			<xsl:call-template name="displayElementName"/>
		</h3>
		<xsl:apply-templates />
	</div>
</xsl:template>

<xsl:template match="xsd:element">
	<div>
		<h3>
		  <xsl:if test="xsd:complexType[not(@*)]">
		  	Complex type:
		  </xsl:if>
			<xsl:call-template name="displayElementName"/>
		</h3>
		<xsl:apply-templates />
	</div>
</xsl:template>

<xsl:template match="@minOccurs">
  <xsl:if test="../@type">
  	<xsl:value-of select="' '" />
  </xsl:if>
	<xsl:value-of select="." />
</xsl:template>

<xsl:template match="@maxOccurs">
	<xsl:value-of select="concat('-', .)" />
</xsl:template>

<xsl:template match="spectrum:unitName">
  <h4>SPECTRUM unit: <xsl:apply-templates /></h4>
</xsl:template>

<xsl:template match="spectrum:description">
  <p><xsl:apply-templates /></p>
</xsl:template>

</xsl:stylesheet>
